Changes
========

v3, 2015-10-12
---------------
Changed the output of ``build_layers()`` and moved layer names into the GeoJSON FeatureCollections

v2.0.2, 2015-10-12
-------------------
- Replaced underscores with dashes in command line options

v2.0.1, 2015-10-12
-------------------
- Set default border style for colored polygons
 
v2, 2015-10-08
------------------
- Added documentation
- Tweaked the command line tool options 

v1, 2015-10-05
------------------
- Changed some names 
- Added lots of tests

v0.1.1, 2015-10-03
-------------------
Fixed packaging to find ``README.rst``

v0.1, 2015-10-03
-----------------
First

